@@ -10,6 +10,7 @@ use JSON::Meth;
 my $data = {
     foo => 'bar',
     baz => 'ber',
+    cow => 'moo',
     mer => [
         meer => 1,
         moor => {
@@ -25,9 +26,9 @@ my $data = {
 
 my $json_str = $data->$j;
 
-say "Our encoded JSON is $json_str";
+say "Our encoded JSON is $json_str"; # print JSON-encoded string
 
-my $same_data = $json_str->$j; # $same_data is now the same as $data
+say $json_str->$j->{cow}; # says "moo"
 
 
 __END__
\ No newline at end of file
